
<img width="1920" alt="fastget" src="https://github.com/user-attachments/assets/70174f0e-8cb3-4521-961b-c910b9be2e29" />

# FastGet
High-speed File Downloading Tool

## How
It's using Multiple Thread Download.

This is need Range-select feature, in Server-side.

## Requiments
- CPython 3.9+
- `pip3` [PyPI↗︎](https://pypi.org/project/pip/) or `uv` [PyPI↗︎](https://pypi.org/project/uv/)
- `nercone-modern` [PyPI↗︎](https://pypi.org/project/nercone-modern/)
- `rich` [PyPI↗︎](https://pypi.org/project/rich/)
- `requests` [PyPI↗︎](https://pypi.org/project/requests/)

## Installation

### using uv (recommended)
```
uv tool install nercone-fastget
```

### using pip3

**System Python:**
```
pip3 install nercone-fastget --break-system-packages
```

**Venv Python:**
```
pip3 install nercone-fastget
```
